import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useState } from 'react';
import { MenuItem, Pagination, Select, Typography, useTheme, } from '@mui/material';
import useMediaQuery from '@mui/material/useMediaQuery';
import { ROW_PER_PAGE } from '../../constants/table-constants';
import { translate } from '../../locales/translations';
import CsvExport from './CsvExport';
import './adminTable-styles.scss';
const AdminTableFooter = (props) => {
    const { currentPage, onPageChange, onRowsPerPageChange, pageSize = 10, title = 'data', totalRecords, isExport = false, isPagination = true, } = props;
    const numberOfPages = Math.ceil(totalRecords / pageSize);
    const theme = useTheme();
    const isMobile = useMediaQuery(theme.breakpoints.down('sm'));
    const [rowsPerPage, setRowsPerPage] = useState(pageSize);
    const handleRowsPerPageChange = (event) => {
        const newRowsPerPage = +event.target.value;
        setRowsPerPage(newRowsPerPage);
        onRowsPerPageChange(newRowsPerPage);
    };
    const handlePageChange = (_, value) => {
        onPageChange(value);
    };
    const renderRowPerPageOptions = () => {
        return ROW_PER_PAGE.map((size) => (_jsx(MenuItem, { value: size, children: size }, size)));
    };
    const renderRowPerPage = () => (_jsxs("div", { className: "adminTable__rowPerPageContainer", children: [_jsx(Typography, { className: "adminTable__rowPerPageLabel", children: translate.components.table.rowPerPage }), _jsx(Select, { value: rowsPerPage, classes: {
                    outlined: 'adminTable__paginationOutlined',
                    root: 'adminTable__paginationSelect',
                }, onChange: handleRowsPerPageChange, displayEmpty: true, children: renderRowPerPageOptions() })] }));
    return (_jsxs("div", { className: "adminTable__footerContainer", children: [isExport && _jsx(CsvExport, { fileName: title }), isPagination && (_jsxs("div", { className: "adminTable__paginationWrapper", children: [renderRowPerPage(), _jsx(Pagination, { page: currentPage ? currentPage : 1, boundaryCount: isMobile ? 1 : 2, className: "adminTable__pagination", count: numberOfPages ? numberOfPages : 1, onChange: handlePageChange, shape: "rounded", showFirstButton: !isMobile, showLastButton: !isMobile, siblingCount: isMobile ? 0 : 1, variant: "outlined" })] }))] }));
};
export default AdminTableFooter;
