import { z } from 'zod';
import { FieldEnum } from '../../constants';
import { PaginationMethod } from '../../types/common-types';
var RewardField;
(function (RewardField) {
    RewardField["RewardUrl"] = "reward_url";
})(RewardField || (RewardField = {}));
const RewardSchema = z.object({
    [RewardField.RewardUrl]: z.string().min(1, 'Reward URL is required'),
});
const RewardsResponseSchema = z.array(RewardSchema);
export const DATA = {
    title: 'Rewards',
    tables: [
        {
            key: 'rewards',
            detailsRoute: '/rewards',
            handleDetailsSubmit: async (data) => {
                console.log('res009', data);
            },
            columns: [
                {
                    field: RewardField.RewardUrl,
                    headerName: "Reward's URL",
                    fieldProps: {
                        fieldType: FieldEnum.UPLOADER,
                    },
                },
            ],
            enableExport: true,
            actions: {
                edit: true,
                delete: true,
                view: true,
                add: true,
                filter: true,
                search: false,
                toggle: false,
            },
            pagination: true,
            paginationMethod: PaginationMethod.OFFSET,
            schema: RewardsResponseSchema,
            defaultValues: {
                [RewardField.RewardUrl]: '',
            },
        },
    ],
};
