import { FieldValues } from 'react-hook-form';
import { DataGridProps, GridRowParams, GridSortModel } from '@mui/x-data-grid';
import { IColumn } from '../types/common-types';
export type ITableActions = {
    add: boolean;
    delete: boolean;
    edit: boolean;
    view: boolean;
    search: boolean;
    toggle?: boolean;
};
export interface IRow {
    [key: string]: string | number;
}
export type ActionClickType<SubmitDataType extends FieldValues> = (row: GridRowParams<SubmitDataType>, actionKey: string) => void;
export interface TableFooterProps {
    totalRecords: number;
    pageSize?: number;
    onRowsPerPageChange: (rowsPerPage: number) => void;
    onPageChange: (page: number) => void;
    currentPage?: number;
    title?: string;
    isExport?: boolean;
    isPagination?: boolean;
}
export interface IFooterFromCrudProps {
    totalRecords?: number;
    pageSize?: number;
    currentPage?: number;
    handleRowsPerPageChange?: (rowsPerPage: number) => void;
    handlePageChange?: (page: number) => void;
}
export interface IFooterFromLayoutProps {
    enableExport?: boolean;
    pagination?: boolean;
}
export interface IAdminTableFooterProps extends IFooterFromCrudProps, IFooterFromLayoutProps {
    title?: string;
}
export interface IAdminTableFromLayoutProps<SubmitDataType extends FieldValues> {
    columns: IColumn<SubmitDataType>[];
}
export interface IAdminTableFromCrudProps<SubmitDataType extends FieldValues> {
    handleActionClick?: (row: GridRowParams<SubmitDataType>, actionKey: string) => void;
    handleRowClick?: (row: GridRowParams<SubmitDataType>) => void;
    handleSort?: (model: GridSortModel) => void;
    isLoading?: boolean;
}
export interface IAdminTableProps<SubmitDataType extends FieldValues> extends Omit<DataGridProps<SubmitDataType>, 'pagination' | 'columns'>, IAdminTableFromCrudProps<SubmitDataType>, IAdminTableFromLayoutProps<SubmitDataType>, IAdminTableFooterProps {
    actions?: ITableActions;
    totalRecords?: number;
    pageSize?: number;
    title?: string;
    toolbarHeader?: React.ReactNode;
    isExport?: boolean;
    handlePagination?: (page: number) => void;
    searchValue?: string | number;
    handleSearch?: (value: string | number) => void;
    handleToggle?: (row: IRow) => void;
    toggleKey?: string;
    disableActionsForRow?: (row: IRow) => boolean;
}
